package com.ruoyi.doubledefense.mapper;

import java.util.List;

import com.ruoyi.doubledefense.domain.FourColorDiagram;
import com.ruoyi.doubledefense.dtoGov.FourColorDiagramDTOGov;

/**
 * 四色图Mapper接口
 *
 * @author lyp
 * @date 2023-09-16
 */
public interface FourColorDiagramMapper {
    /**
     * 四色图
     * 重预防汇聚计算节点
     *
     * @param fourColorDiagramDTOGov
     * @return
     */
    List<FourColorDiagramDTOGov> govSelectFourColorDiagramList(FourColorDiagramDTOGov fourColorDiagramDTOGov);

    /**
     * 查询四色图
     *
     * @param id 四色图主键
     * @return 四色图
     */
    public FourColorDiagram selectFourColorDiagramById(String id);

    /**
     * 查询四色图列表
     *
     * @param fourColorDiagram 四色图
     * @return 四色图集合
     */
    public List<FourColorDiagram> selectFourColorDiagramList(FourColorDiagram fourColorDiagram);

    /**
     * 新增四色图
     *
     * @param fourColorDiagram 四色图
     * @return 结果
     */
    public int insertFourColorDiagram(FourColorDiagram fourColorDiagram);

    /**
     * 修改四色图
     *
     * @param fourColorDiagram 四色图
     * @return 结果
     */
    public int updateFourColorDiagram(FourColorDiagram fourColorDiagram);

    /**
     * 删除四色图
     *
     * @param id 四色图主键
     * @return 结果
     */
    public int deleteFourColorDiagramById(String id);

    /**
     * 批量删除四色图
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFourColorDiagramByIds(String[] ids);
}
